@@ -1,5 +1,5 @@
 #
-# $Id: Splunk.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Splunk.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # api::splunk Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Rest);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable rest) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -97,7 +97,7 @@ sub search_jobs {
    my $code = $self->code;
 
    $self->log->verbose("search_jobs: returned code [$code]");
-   $self->debug && $self->log->debug("search_jobs: content [".$resp->{content}."]");
+   $self->log->debug("search_jobs: content [".$resp->{content}."]");
 
    if ($code == 201) {  # Job created
       return $self->content('xml');
@@ -119,7 +119,7 @@ sub search_jobs_sid {
    my $code = $self->code;
 
    $self->log->verbose("search_jobs_sid: returned code [$code]");
-   $self->debug && $self->log->debug("search_jobs_sid: content [".$resp->{content}."]");
+   $self->log->debug("search_jobs_sid: content [".$resp->{content}."]");
 
    if ($code == 404) {
       return 0;
@@ -153,7 +153,7 @@ sub search_jobs_sid_results {
    my $code = $self->code;
 
    $self->log->verbose("search_jobs_sid_results: returned code [$code]");
-   $self->debug && $self->log->debug("search_jobs_sid_results: content [".$resp->{content}."]");
+   $self->log->debug("search_jobs_sid_results: content [".$resp->{content}."]");
 
    if ($code == 200) {  # Job finished
       return $self->content($output_mode);
@@ -201,7 +201,7 @@ sub data_lookup_table_files_acl {
    my $code = $self->code;
 
    $self->log->verbose("data_lookup_table_files_acl: returned code [$code]");
-   $self->debug && $self->log->debug("data_lookup_table_files_acl: content [".$resp->{content}."]");
+   $self->log->debug("data_lookup_table_files_acl: content [".$resp->{content}."]");
 
    return $self->content('xml');
 }
@@ -249,7 +249,7 @@ Metabrik::Api::Splunk - api::splunk Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
