@@ -1,5 +1,5 @@
 #
-# $Id: Dns.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Dns.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # audit::dns Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -58,7 +58,7 @@ sub version {
          nameservers => [ $nameserver ],
          recurse => 0,
          searchlist => [],
-         debug => $self->debug,
+         debug => $self->log->level > 2 ? 1 : 0,
          udp_timeout => $self->rtimeout,
          tcp_timeout => $self->rtimeout,
       ) or return $self->log->error("version: Net::DNS::Resolver::new failed");
@@ -99,7 +99,7 @@ sub recursion {
          nameservers => [ $nameserver ],
          recurse => 1,
          searchlist => [],
-         debug => $self->debug,
+         debug => $self->log->level > 2 ? 1 : 0,
          udp_timeout => $self->rtimeout,
          tcp_timeout => $self->rtimeout,
       ) or return $self->log->error("recursion: Net::DNS::Resolver::new failed");
@@ -139,7 +139,7 @@ sub axfr {
          nameservers => [ $nameserver ],
          recurse => 0,
          searchlist => ref($domainname) eq 'ARRAY' ? $domainname : [ $domainname ],
-         debug => $self->debug,
+         debug => $self->log->level > 2 ? 1 : 0,
          udp_timeout => $self->rtimeout,
          tcp_timeout => $self->rtimeout,
       ) or return $self->log->error("axfr: Net::DNS::Resolver::new failed");
@@ -187,7 +187,7 @@ Metabrik::Audit::Dns - audit::dns Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
