@@ -1,5 +1,5 @@
 #
-# $Id: Redis.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Redis.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # client::redis Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::System::Service Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -69,9 +69,9 @@ sub connect {
    my $redis = Redis->new(
       server => $self->server.':'.$self->port,
       name => 'redis_connection',
-      cnx_timeout => $self->global->ctimeout,
-      read_timeout => $self->global->rtimeout,
-      write_timeout => $self->global->rtimeout,
+      cnx_timeout => defined($self->global) && $self->global->ctimeout || 3,
+      read_timeout => defined($self->global) && $self->global->rtimeout || 3,
+      write_timeout => defined($self->global) && $self->global->rtimeout || 3,
    ) or return $self->log->error("connect: redis connection error");
 
    return $self->_redis($redis);
@@ -285,7 +285,7 @@ Metabrik::Client::Redis - client::redis Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
