@@ -1,5 +1,5 @@
 #
-# $Id: Tcpdump.pm,v a483f00cce99 2017/03/20 16:50:45 gomor $
+# $Id: Tcpdump.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # client::tcpdump Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Network::Read);
 
 sub brik_properties {
    return {
-      revision => '$Revision: a483f00cce99 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -43,7 +43,7 @@ sub brik_use_properties {
 
    return {
       attributes_default => {
-         device => $self->global->device,
+         device => defined($self->global) && $self->global->device || 'eth0',
       },
    };
 }
@@ -148,7 +148,7 @@ Metabrik::Client::Tcpdump - client::tcpdump Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
