@@ -1,5 +1,5 @@
 #
-# $Id: Rir.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Rir.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # database::rir Brik
 #
@@ -14,7 +14,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable as country subnet) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -107,7 +107,7 @@ sub next_record {
 
       chomp($line);
 
-      $self->debug && $self->log->debug("next_record: line[$line]");
+      $self->log->debug("next_record: line[$line]");
 
       my @t = split(/\|/, $line);
 
@@ -199,7 +199,7 @@ Metabrik::Database::Rir - database::rir Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
