@@ -1,5 +1,5 @@
 #
-# $Id: Mojo.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Mojo.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # devel::mojo Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -43,18 +43,27 @@ sub generate_lite_app {
    my $self = shift;
    my ($pl) = @_;
 
-   my $she = $self->shell;
    my $datadir = $self->datadir;
    $self->brik_help_run_undef_arg('generate_lite_app', $pl) or return;
 
-   my $cwd = $she->pwd;
+   my $cwd = defined($self->shell) && $self->shell->pwd || '/tmp';
 
-   $she->run_cd($datadir) or return;
+   if (defined($self->shell)) {
+      $self->shell->run_cd($datadir) or return;
+   }
+   else {
+      chdir($datadir) or return $self->log->error("generate_lite_app: chdir: $!");
+   }
 
    my $cmd = "mojo generate lite_app \"$pl\"";
    my $r = $self->execute($cmd);
 
-   $she->run_cd($cwd) or return;
+   if (defined($self->shell)) {
+      $self->shell->run_cd($cwd) or return;
+   }
+   else {
+      chdir($cwd) or return $self->log->error("generate_lite_app: chdir: $!");
+   }
 
    return $r;
 }
@@ -63,18 +72,27 @@ sub generate_app {
    my $self = shift;
    my ($module) = @_;
 
-   my $she = $self->shell;
    my $datadir = $self->datadir;
    $self->brik_help_run_undef_arg('generate_app', $module) or return;
 
-   my $cwd = $she->pwd;
+   my $cwd = defined($self->shell) && $self->shell->pwd || '/tmp';
 
-   $she->run_cd($datadir) or return;
+   if (defined($self->shell)) {
+      $self->shell->run_cd($datadir) or return;
+   }
+   else {
+      chdir($datadir) or return $self->log->error("generate_app: chdir: $!");
+   }
 
    my $cmd = "mojo generate app \"$module\"";
    my $r = $self->execute($cmd);
 
-   $she->run_cd($cwd) or return;
+   if (defined($self->shell)) {
+      $self->shell->run_cd($cwd) or return;
+   }
+   else {
+      chdir($cwd) or return $self->log->error("generate_app: chdir: $!");
+   }
 
    return $r;
 }
@@ -95,19 +113,28 @@ sub inflate {
    my $self = shift;
    my ($pl) = @_;
 
-   my $she = $self->shell;
    my $datadir = $self->datadir;
    $self->brik_help_run_undef_arg('inflate', $pl) or return;
    $self->brik_help_run_file_not_found('inflate', $pl) or return;
 
-   my $cwd = $she->pwd;
+   my $cwd = defined($self->shell) && $self->shell->pwd || '/tmp';
 
-   $she->run_cd($datadir) or return;
+   if (defined($self->shell)) {
+      $self->shell->run_cd($datadir) or return;
+   }
+   else {
+      chdir($datadir) or return $self->log->error("inflate: chdir: $!");
+   }
 
    my $cmd = "perl \"$pl\" inflate";
    my $r = $self->execute($cmd);
 
-   $she->run_cd($cwd) or return;
+   if (defined($self->shell)) {
+      $self->shell->run_cd($cwd) or return;
+   }
+   else {
+      chdir($cwd) or return $self->log->error("inflate: chdir: $!");
+   }
 
    return $r;
 }
@@ -159,7 +186,7 @@ Metabrik::Devel::Mojo - devel::mojo Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
