@@ -1,5 +1,5 @@
 #
-# $Id: Send.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Send.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # email::send Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Network::Smtp);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable smtp) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -19,11 +19,15 @@ sub brik_properties {
          from => [ qw(from) ],
          to => [ qw(to) ],
          subject => [ qw(subject) ],
+         server => [ qw(server) ],
+         port => [ qw(port) ],
       },
       attributes_default => {
          from => 'from@example.com',
          to => 'to@example.com',
          subject => 'My subject',
+         server => 'localhost',
+         port => 25,
       },
       commands => {
          send => [ qw(email from|OPTIONAL to|OPTIONAL subject|OPTIONAL) ],
@@ -97,7 +101,7 @@ Metabrik::Email::Send - email::send Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
