@@ -1,5 +1,5 @@
 #
-# $Id: Raw.pm,v 4f5647eb9e58 2017/03/05 12:22:13 gomor $
+# $Id: Raw.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # file::raw Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Write);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 4f5647eb9e58 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable read write) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -61,7 +61,7 @@ sub write {
    $self->brik_help_run_undef_arg('write', $data) or return;
    $self->brik_help_run_undef_arg('write', $output) or return;
 
-   $self->debug && $self->log->debug("write: data[$data]");
+   $self->log->debug("write: data[$data]");
 
    $self->open($output) or return;
    $self->SUPER::write($data) or return;
@@ -80,7 +80,7 @@ Metabrik::File::Raw - file::raw Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
