@@ -1,5 +1,5 @@
 #
-# $Id: Address.pm,v 5051a354bfa9 2017/10/28 08:17:02 gomor $
+# $Id: Address.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # network::address Brik
 #
@@ -11,12 +11,14 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 5051a354bfa9 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable netmask convert ascii) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          subnet => [ qw(subnet) ],
+         _ipv4_re => [ qw(INTERNAL) ],
+         _ipv6_re => [ qw(INTERNAL) ],
       },
       commands => {
          match => [ qw(ip_address subnet|OPTIONAL) ],
@@ -60,10 +62,26 @@ sub brik_properties {
          'NetAddr::IP' => [ ],
          'Net::CIDR' => [ ],
          'Socket' => [ ],
+         'Regexp::IPv4' => [ qw($IPv4_re) ],
+         'Regexp::IPv6' => [ qw($IPv6_re) ],
       },
    };
 }
 
+sub brik_init {
+   my $self = shift;
+
+   my $init = $self->SUPER::brik_init or return;
+
+   my $ipv4_re = qr/^${Regexp::IPv4::IPv4_re}$/;
+   my $ipv6_re = qr/^${Regexp::IPv6::IPv6_re}$/;
+
+   $self->_ipv4_re($ipv4_re);
+   $self->_ipv6_re($ipv6_re);
+
+   return $init;
+}
+
 sub match {
    my $self = shift;
    my ($ip, $subnet) = @_;
@@ -156,8 +174,6 @@ sub is_ip {
 
    $self->brik_help_run_undef_arg('is_ip', $ip) or return;
 
-   (my $local = $ip) =~ s/\/\d+$//;
-
    if ($self->is_ipv4($ip) || $self->is_ipv6($ip)) {
       return 1;
    }
@@ -198,7 +214,9 @@ sub is_ipv4 {
 
    (my $local = $ip) =~ s/\/\d+$//;
 
-   if ($local =~ /^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/) {
+   my $ipv4_re = $self->_ipv4_re;
+
+   if ($local =~ $ipv4_re) {
       return 1;
    }
 
@@ -213,13 +231,10 @@ sub is_ipv6 {
 
    (my $local = $ip) =~ s/\/\d+$//;
 
-   if ($local =~ /^[0-9a-f:\/]+$/i) {
-      eval {
-         my $x = Net::IPv6Addr::ipv6_parse($local);
-      };
-      if (! $@) {
-         return 1;
-      }
+   my $ipv6_re = $self->_ipv6_re;
+
+   if ($local =~ $ipv6_re) {
+      return 1;
    }
 
    return 0;
@@ -388,12 +403,12 @@ sub is_ipv4_subnet {
 
    my ($address, $cidr) = $subnet =~ m{^(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/(\d+)$};
    if (! defined($address) || ! defined($cidr)) {
-      $self->debug && $self->log->debug("is_ipv4_subnet: not a subnet [$subnet]");
+      $self->log->debug("is_ipv4_subnet: not a subnet [$subnet]");
       return 0;
    }
 
    if ($cidr < 0 || $cidr > 32) {
-      $self->debug && $self->log->debug("is_ipv4_subnet: not a valid CIDR mask [$cidr]");
+      $self->log->debug("is_ipv4_subnet: not a valid CIDR mask [$cidr]");
       return 0;
    }
 
@@ -653,7 +668,7 @@ Metabrik::Network::Address - network::address Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
