@@ -1,5 +1,5 @@
 #
-# $Id: Write.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Write.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # network::write Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable ethernet ip raw socket) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -48,9 +48,9 @@ sub brik_use_properties {
    return {
       attributes_default => {
          layer => 2,
-         device => $self->global->device,
-         family => $self->global->family,
-         protocol => $self->global->protocol,
+         device => defined($self->global) && $self->global->device || 'eth0',
+         family => defined($self->global) && $self->global->family || 'ipv4',
+         protocol => defined($self->global) && $self->global->protocol || 'tcp',
       },
    };
 }
@@ -250,7 +250,7 @@ Metabrik::Network::Write - network::write Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
