@@ -1,5 +1,5 @@
 #
-# $Id: Script.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Script.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # shell::script Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(scripting) ],
       attributes => {
          input => [ qw(file) ],
@@ -51,6 +51,10 @@ sub execute {
    my $self = shift;
    my ($lines) = @_;
 
+   if (! defined($self->shell)) {
+      return $self->log->error("execute: no core::shell Brik");
+   }
+
    $self->brik_help_run_undef_arg('execute', $lines) or return;
    $self->brik_help_run_invalid_arg('execute', $lines, 'ARRAY') or return;
 
@@ -81,7 +85,7 @@ Metabrik::Shell::Script - shell::script Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
