@@ -1,5 +1,5 @@
 #
-# $Id: Package.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Package.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # system::package Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -46,7 +46,7 @@ sub brik_properties {
 sub get_system_package {
    my $self = shift;
 
-   my $os = $self->my_os;
+   my $os = $self->my_os or return;
    my $sudo_args = $self->sudo_args;
 
    my $sp;
@@ -235,7 +235,7 @@ Metabrik::System::Package - system::package Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
